@@ -1,3 +1,4 @@
+use std::error;
 use std::fmt;
 
 #[derive(Debug, PartialEq)]
@@ -5,6 +6,8 @@ pub enum Error {
     Parameter(String),
 }
 
+impl error::Error for Error {}
+
 impl fmt::Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match *self {
